﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Storage;
using System.IO;
using System.Threading.Tasks;
using Windows.Storage;

namespace P22_1
{
    public partial class FileViewPage : PhoneApplicationPage
    {
        // Маркер файла, полученныый при запуске приложения по сопоставлению с типом файла
        private string _fileToken;

        // Путь к файлу на SD-карте, переданный при вызове из MainPage.xaml.cs.
        private string _sdFilePath;

        private const string MYAPP_FOLDER_NAME = "Myapp_external";

        public FileViewPage()
        {
            InitializeComponent();
        }

        // Получение либо пути к файлу, либо маркера, в зависимости от того, как открыта страница 
        protected override async void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            // Открытие по сопоставлению с типом файла.
            if (NavigationContext.QueryString.ContainsKey("fileToken"))
            {
                _fileToken = NavigationContext.QueryString["fileToken"];
                await ProcessExternalFile(_fileToken);
            }
            // Открыти для чтения файла с SD-карты
            else if (NavigationContext.QueryString.ContainsKey("sdFilePath"))
            {
                _sdFilePath = NavigationContext.QueryString["sdFilePath"];
                await ProcessFile(_sdFilePath);
            }
        }

        // Обработка файла с SD-карты.
        private async Task ProcessFile(string _sdFilePath)
        {
            // Подключение к SD-карте.
            ExternalStorageDevice sdCard = (await ExternalStorage.GetExternalStorageDevicesAsync()).FirstOrDefault();

            // Если подключиться удалось, читаем файл с карты
            
            if (sdCard != null)
            {
                try
                {
                    // Получаем файл с SD-карты.
                    ExternalStorageFile file = await sdCard.GetFileAsync(_sdFilePath);

                    // Создаём поток.
                    Stream s = await file.OpenForReadAsync();

                    // Читаем данные из файла.
                    ReadFile(s);
                    // Обновлям заголовок страницы
                    txtPageName.Text = "файл с карты";
                }
                catch (FileNotFoundException)
                {
                    // Файла нет на SD-карте.
                    MessageBox.Show("Запрошенного файла нет на карте");
                }
            }
            else
            {
                // Нет SD-карты.
                MessageBox.Show("SD-карта не найдена. Подключите SD-карту, на которой есть папка Myapp с хотя бы одним .myapp-файлом и попробуйте снова.");
            }
        }

        // Обработка внешнего файла, для открытия которого вызвано приложение.
        public async Task ProcessExternalFile(string fileToken)
        {
            // Создадим или откроем папку Myapp_external.
            IStorageFolder myappFolder = await Windows.Storage.ApplicationData.Current.LocalFolder.CreateFolderAsync(MYAPP_FOLDER_NAME, CreationCollisionOption.OpenIfExists);

            // Получим полное имя открываемого файла.
            string incomingMyappFilename = Windows.Phone.Storage.SharedAccess.SharedStorageAccessManager.GetSharedFileName(fileToken);

            // Скопируем .myapp-файл в папку Myapp_external.
            IStorageFile routeFile = await Windows.Phone.Storage.SharedAccess.SharedStorageAccessManager.CopySharedFileAsync((StorageFolder)myappFolder, incomingMyappFilename, NameCollisionOption.GenerateUniqueName, fileToken);

            // Создадим поток.
            var s = await routeFile.OpenReadAsync();

            // Читаем данные из файла.
            ReadFile(s.AsStream());

            txtPageName.Text = "файл извне";
        }

        // Чтение данных файла из потока
        public void ReadFile(System.IO.Stream routeStream)
        {
           StreamReader sr = new StreamReader(routeStream);
           txtFileContent.Text = sr.ReadToEnd();
       }
    }
}