﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Storage;
using System.Collections.ObjectModel;
using System.IO;
namespace P22_1
{
    public partial class MainPage : PhoneApplicationPage
    {
        //Коллекция .myapp - файлов для привязки к списку
       
        public ObservableCollection<ExternalStorageFile> MyAppFiles { get; set; }

        // Конструктор
        public MainPage()
        {
            InitializeComponent();

            // Инициализация коллекции файлов.
            MyAppFiles = new ObservableCollection<ExternalStorageFile>();

            // Привязка страницы к своим данным.
            this.DataContext = this;
        }

        // Сканирование SD-карты в поиске .myapp-файлов
        private async void scanExternalStorageButton_Click_1(object sender, RoutedEventArgs e)
        {
            // Очистка коллекции, привязанной к странице
            MyAppFiles.Clear();

            // Подключение к SD-карте
            ExternalStorageDevice _sdCard = (await ExternalStorage.GetExternalStorageDevicesAsync()).FirstOrDefault();

            // Если SD-карта подключена к устройству, добавляем .myapp-файл в коллекцию.
            if (_sdCard != null)
            {
                try
                {
                    // Обнаружение папки Myapp на SD-карте.
                    ExternalStorageFolder myappFolder = await _sdCard.GetFolderAsync("Myapp");

                    // Получение файлов, с которыми может работать приложение, из папки.
                    IEnumerable<ExternalStorageFile> myappFiles = await myappFolder.GetFilesAsync();

                    // Добавление .myapp-файлов в коллекцию
                    foreach (ExternalStorageFile esf in myappFiles)
                    {
                        if (esf.Path.EndsWith(".myapp"))
                        {
                            MyAppFiles.Add(esf);
                        }
                    }
                }
                catch (FileNotFoundException)
                {
                    // Нет папки Myapp.
                    MessageBox.Show("На SD-карте нет папки Myapp. Добавьте на карту эту папку, разместите в ней хотя бы один .myapp-файл и попробуйте снова.");
                }
            }
            else
            {
                // Нет SD-карты.
                MessageBox.Show("SD-карта не найдена. Подключите SD-карту, на которой есть папка Myapp с хотя бы одним .myapp-файлом и попробуйте снова.");
            }
        }


        // При выборе файла выполняется вызов страницы FileViewPage с передачей ей пути к файлу
        
        private void myappFilesListBox_SelectionChanged_1(object sender, SelectionChangedEventArgs e)
        {
            ListBox lb = (ListBox)sender;

            if (lb.SelectedItem != null)
            {
                ExternalStorageFile esf = (ExternalStorageFile)lb.SelectedItem;
                NavigationService.Navigate(new Uri("/FileViewPage.xaml?sdFilePath=" + esf.Path, UriKind.Relative));
            }
        }
    }
}
